
/*

This file 
-appends years of collapsed claims data
-merges utilization data with predicted utilization from ACG output
-creates a limited set of constructed vars.

*/

*----------------------------------------------------
*----------------------------------------------------
* Load data
*----------------------------------------------------
*----------------------------------------------------

clear
clear matrix
set mem 10g
set more off

global SOURCE "/disk/aging/medstat/data/sas"
global BULK "/disk/agebulk2/medstat.work/gerusom"
global WORK "/disk/agedisk3/medstat.work/gerusom"
global SCRATCH "/disk/agescratch4/gerusom"

use "$WORK/Costs_andCounts_2003.dta", clear
replace year=2003 if year==.

append using "$WORK/Costs_andCounts_2004.dta"
replace year=2004 if year==.
append using "$WORK/Costs_andCounts_2005.dta"
replace year=2005 if year==.
append using "$WORK/Costs_andCounts_2006.dta"
replace year=2006 if year==.
append using "$WORK/Costs_andCounts_2007.dta"
replace year=2007 if year==.


*----------------------------------------------------
*Merge Predictions of Cost
*----------------------------------------------------

forvalues i=3(1)6{

	sort patient_id
	cap drop _merge
	merge m:1 patient_id using "$BULK/ACG/Pred_200`i'.dta",
}

cap drop merge 

*----scale prediction by total avg cost in population
*need to do this before restricting sample

gen totpay = out_totpay + in_totpay + pharm_totpay
label var totpay "in, out, and pharma costs"

gen totdoc = out_totpay + in_totpay
label var totdoc "in, and outpatient costs"

*to create predictions, must multiply relative risk index by avg expenditure in population
*has to be the entire population over which the ACG model was estimated

forvalues i=4(1)7{

	cap drop avg_tot_200`i'
	egen avg_tot_200`i' = mean(totpay) if year==200`i'  & pred_dxrx_l_tot_200`i'~=.
	cap drop pred_tot_200`i'
	gen pred_tot_200`i' = avg_tot_200`i'*pred_dxrx_l_tot_200`i'
	
	cap drop avg_pharm_200`i'
	egen avg_pharm_200`i' = mean(pharm_totpay) if year==200`i' & pred_dxrx_l_pharm_200`i'~=.
	cap drop pred_pharm_200`i'
	gen pred_pharm_200`i' = avg_pharm_200`i'*pred_dxrx_l_pharm_200`i'
	
	cap drop avg_pharm_200`i'
	cap drop avg_tot_200`i'
}

/*
*Checks

summ pred_tot_2005 if year==2005, d
summ totpay if year==2005, d

reg totpay pred_tot_2004 if year==2004, r
reg totpay pred_tot_2005 if year==2005, r
reg totpay pred_tot_2006 if year==2006, r
reg totpay pred_tot_2007 if year==2007, r 

lpoly totpay pred_tot_2004 if year==2004 & pred_tot_2004<10000, noscatter
lpoly totpay pred_tot_2005 if year==2005 & pred_tot_2005<10000, noscatter
lpoly totpay pred_tot_2006 if year==2006 & pred_tot_2006<10000, noscatter
lpoly totpay pred_tot_2007 if year==2007 & pred_tot_2007<10000, noscatter

*/


*----------------------------------------------------
* Basic Vars
*----------------------------------------------------

*----Demographics

gen fem = 0 if sex=="1"
replace fem = 1 if sex=="2"

drop sex

*get family id, which is just enrolid except for last two digits
tostring enrolid, gen(idstring) force
gen idreverse = reverse(idstring)
gen famreverse = substr(idreverse, 3,.)
gen famid = reverse(famreverse)
drop idreverse famreverse

egen tag_fam = tag(famid)
destring emprel, force replace
egen tag_empid = tag(enrolid) if emprel==1

cap drop flag*
cap drop self 
cap drop spouse child
gen self = (emprel==1)
egen flag_self = max(self), by(famid year)
gen spouse = (emprel==2)
egen flag_spouse = max(spouse), by(famid year)
gen child = (emprel==3)
egen flag_child = total(child), by(famid year)

cap drop ones
gen ones = 1
cap drop count_fam
egen count_fam = total(ones), by(famid year)

egen famcount_max = max(count_fam), by(famid)
egen famcount_min = min(count_fam), by(famid)
gen temp = (famcount_max~=famcount_min)
egen sizechange = max(temp), by(famid)
label var sizechange "indicator: diff number of fam members in diff years"

cap drop I_size*
gen byte I_size1 = 0
replace I_size1 = 1 if count_fam==1
gen byte I_size2 = 0
replace I_size2 = 1 if count_fam==2
gen byte I_size3 = 0
replace I_size3 = 1 if count_fam==3
gen byte I_size4 = 0
replace I_size4 = 1 if count_fam>=4 & count_fam<=8

cap drop ag2
gen ag2 = .
replace ag2=1 if age>=18 & age<=29
replace ag2=2 if age>=30 & age<=39
replace ag2=3 if age>=40 & age<=49
replace ag2=4 if age>=50 & age<=59
replace ag2=5 if age>=60 & age<=64

cap drop I_ag2*
ta ag2, gen(I_ag2_)
label var I_ag2_1 "18-29"
label var I_ag2_2 "30-39"
label var I_ag2_3 "40-49"
label var I_ag2_4 "50-59"


*----Panel and Utilization Vars


*Replace less than zeros with zero
replace totpay=0 if totpay<0
replace pharm_totpay=0 if pharm_totpay<0
replace totdoc=0 if totdoc<0

forvalues j=2003(1)2007{

	cap drop temp*
	cap drop totdoc_`j'
	egen temp2 = max(totdoc) if year==`j', by(enrolid)
	egen totdoc_`j' = max(temp2), by(enrolid)
}

forvalues j=2003(1)2007{

	cap drop temp*
	cap drop totpay_`j'
	egen temp1 = max(totpay) if year==`j', by(enrolid)
	egen totpay_`j' = max(temp1), by(enrolid)
}

forvalues j=2003(1)2007{

	cap drop temp*
	cap drop totpharm_`j'
	egen temp3 = max(pharm_totpay) if year==`j', by(enrolid)
	egen totpharm_`j' = max(temp3), by(enrolid)
}
cap drop temp*


forvalues j=2003(1)2007{

	cap drop nopay_`j'

	gen byte nopay_`j' = 0 if totpay_`j'~=.
	replace nopay_`j' = 1 if totpay_`j'==0
	
	gen byte nodoc_`j' = 0 if totdoc_`j'~=.
	replace nodoc_`j' = 1 if totdoc_`j'==0
}

forvalues j=2003(1)2007{

	cap drop insample_`j'
	gen byte insample_`j' = 0
	cap drop temp_`j' 
	cap drop temp2_`j'
	egen temp_`j' = total(ones) if year==`j', by(enrolid)
	egen temp2_`j' = max(temp_`j'), by(enrolid)
	ta temp2_`j'
	replace insample_`j' = 1 if temp2_`j' ==1  
	label var insample_`j' "present in sample in `j', possibly with varying fam sizes"

}

forvalues j=2003(1)2007{
	cap drop fth_tot_`j'
	gen fth_tot_`j' = (totpay_`j')^.25
}

forvalues j=2003(1)2007{
	cap drop fth_doc_`j'
	gen fth_doc_`j' = (totdoc_`j')^.25
}


gen predtot=.
gen predpharm = .
forvalues yr=2004(1)2007{
	replace predtot = pred_tot_`yr' if year==`yr' & totpay~=.
	replace predpharm = pred_pharm_`yr' if year==`yr' & totpay~=.
}

gen preddoc = predtot - predpharm
replace preddoc=0 if preddoc<0
reg totdoc preddoc, r
label var preddoc "ACG prediction of tot-pharma"

gen fth_predtot = predtot^.25
gen fth_preddoc = preddoc^.25


*----Worker characteristics

cap drop ft
gen ft = (eestat=="1")

cap drop hourly
gen hourly=0
replace hourly=1 if eeclass=="4" | eeclass=="5" | eeclass=="6"

cap drop union
gen union =0
replace union = 1 if eeclass=="2" | eeclass=="5" | eeclass=="8"

destring egeoloc, force replace

gen fips =.
replace fips=9 if ege==4
replace fips=23 if ege==5
replace fips=25 if ege==6
replace fips=33 if ege==7
replace fips=44 if ege==8
replace fips=50 if ege==9
replace fips=34 if ege==11
replace fips=36 if ege==12
replace fips=42 if ege==13
replace fips=17 if ege==16
replace fips=18 if ege==17
replace fips=26 if ege==18
replace fips=39 if ege==19
replace fips=55 if ege==20
replace fips=19 if ege==22
replace fips=20 if ege==23
replace fips=27 if ege==24
replace fips=29 if ege==25
replace fips=31 if ege==26
replace fips=38 if ege==27
replace fips=46 if ege==28
replace fips=11 if ege==31
replace fips=10 if ege==32
replace fips=12 if ege==33
replace fips=13 if ege==34
replace fips=24 if ege==35
replace fips=37 if ege==36
replace fips=45 if ege==37
replace fips=51 if ege==38
replace fips=54 if ege==39
replace fips=1 if ege==41
replace fips=21 if ege==21
replace fips=28 if ege==28
replace fips=47 if ege==44
replace fips=5 if ege==46
replace fips=22 if ege==47
replace fips=40 if ege==48
replace fips=48 if ege==49
replace fips=4 if ege==52
replace fips=8 if ege==53
replace fips=16 if ege==54
replace fips=30 if ege==55
replace fips=32 if ege==56
replace fips=35 if ege==57
replace fips=49 if ege==58
replace fips=56 if ege==59
replace fips=2 if ege==61
replace fips=6 if ege==62
replace fips=15 if ege==63
replace fips=41 if ege==64
replace fips=53 if ege==65

//Link the High/Low plans across plan years, based on "plankey"

cap drop B_*

gen B_hour =.
gen B_sal =.
label var B_hour "Plan B, hourly empl only"
label var B_sal "Plan B, salary empl only"

*2005
replace B_hour = 0 if hourly==1 & plank==2526
replace B_hour = 1 if hourly==1 & plank==2520 

replace B_sal = 0 if hourly==0 & plank==2525
replace B_sal = 1 if hourly==0 & plank==2527 

*2006
replace B_hour = 0 if hourly==1 & plank==2528
replace B_hour = 1 if hourly==1 & plank==2529 

replace B_sal = 0 if hourly==0 & plank==2528
replace B_sal = 1 if hourly==0 & plank==2529 

*2007
replace B_hour = 0 if hourly==1 & plank==2530
replace B_hour = 1 if hourly==1 & plank==2531 

replace B_sal = 0 if hourly==0 & plank==2530
replace B_sal = 1 if hourly==0 & plank==2531 


*---Alt definitions of plan B

*this includes the "out of area" ppl in 2005
gen B2_hour = B_hour
gen B2_sal = B_sal
label var B2_hour "Plan B, looser def, hourly empl only"
label var B2_sal "Plan B, looser def, salary empl only"

replace B2_hour=0 if plank==2522 
replace B2_hour=1 if plank==2524
replace B2_sal=0 if plank==2521 
replace B2_sal=1 if plank==2523

*this lumps together (4) 2004 plans into (2) plans, the pairs of lumped plans seem to differ only in drug coverage

replace B2_hour=0 if hourly==1 & plank==2515 | plank==2518 
replace B2_hour=1 if hourly==1 & plank==2516 | plank==2519 
replace B2_sal=0 if hourly==0 & plank==2515 | plank==2518
replace B2_sal=1 if hourly==0 & plank==2516 | plank==2519 



save "$WORK/Cleaned_merged_MAY072011.dta", replace





